@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.92';
+our $VERSION = '0.93';
 
 use File::Which qw( which );
 
@@ -21,6 +21,12 @@ has has_xs => (
     default => 0,
 );
 
+has wall_min_perl_version => (
+    is      => 'ro',
+    isa     => 'Str',
+    default => '5.008008',
+);
+
 with 'Dist::Zilla::Plugin::DROLSKY::Role::CoreCounter';
 
 # Dist::Zilla provides no way to pass a `-j` option when running dzil release
@@ -35,10 +41,13 @@ override _build_WriteMakefile_dump => sub {
     my $dump = super();
     return $dump unless $self->has_xs;
 
-    $dump .= <<'EOF';
+    my $wall_min_version = $self->wall_min_version;
+
+    $dump .= sprintf( <<'EOF', $self->wall_min_version );
 my $gcc_warnings = $ENV{AUTHOR_TESTING} ? q{ -Wall -Werror} : q{};
 $WriteMakefileArgs{DEFINE}
-    = ( $WriteMakefileArgs{DEFINE} || q{} ) . $gcc_warnings;
+    = ( $WriteMakefileArgs{DEFINE} || q{} ) . $gcc_warnings
+    if $] >= %s;
 
 EOF
 
@@ -63,7 +72,7 @@ Dist::Zilla::Plugin::DROLSKY::MakeMaker - Subclasses MakeMaker::Awesome to alway
 
 =head1 VERSION
 
-version 0.92
+version 0.93
 
 =for Pod::Coverage .*
 
